@@ -3,6 +3,8 @@ from rest_framework.authtoken.models import Token
 from .auth_token_serializer import AuthTokenSerializer
 from rest_framework.response import Response
 from rest_framework.views import APIView
+from django.conf import settings
+from ..models.refresh_token import RefreshToken
 
 
 class ObtainAuthToken(APIView):
@@ -18,7 +20,14 @@ class ObtainAuthToken(APIView):
         serializer.is_valid(raise_exception=True)
         user = serializer.validated_data['user']
         token, created = Token.objects.get_or_create(user=user)
-        return Response({'token': token.key})
+        refresh_token, created_refresh_token = RefreshToken.objects.get_or_create(user=user)
+        return Response({
+            'access_token': token.key,
+            'refresh_token': refresh_token.key,
+            'token_type': 'Bearer',
+            'access_token_expires': settings.GARPIX_ACCESS_TOKEN_TTL_SECONDS,
+            'refresh_token_expires': settings.GARPIX_REFRESH_TOKEN_TTL_SECONDS,
+        })
 
 
 obtain_auth_token = ObtainAuthToken.as_view()
